"use strict";
/**
 * Exposes common HTTP errors with a preconfigured `statusCode` for convenience.
 * This does not mean you have to use HTTP to use them, it's just that
 * HTTP has already defined a nice set of common error types, and tacking
 * on the HTTP status code makes it easier to consume in HTTP apps.
 */
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var make_error_class_1 = require("./make-error-class");
/** *********************************************
 * List of all CLIENT Errors (4xx)
 */
/**
 * Creates a `BadRequest` error.
 */
var BadRequest = /** @class */ (function (_super) {
    tslib_1.__extends(BadRequest, _super);
    function BadRequest() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return BadRequest;
}(MakeHttpError(400, 'Bad Request')));
exports.BadRequest = BadRequest;
/**
 * Creates a `NotAuthenticated` error.
 */
var NotAuthenticated = /** @class */ (function (_super) {
    tslib_1.__extends(NotAuthenticated, _super);
    function NotAuthenticated() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return NotAuthenticated;
}(MakeHttpError(401, 'Not Authenticated')));
exports.NotAuthenticated = NotAuthenticated;
/**
 * Creates a `PaymentRequired` error.
 */
var PaymentRequired = /** @class */ (function (_super) {
    tslib_1.__extends(PaymentRequired, _super);
    function PaymentRequired() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return PaymentRequired;
}(MakeHttpError(402, 'Payment Required')));
exports.PaymentRequired = PaymentRequired;
/**
 * Creates a `Forbidden` error.
 */
var Forbidden = /** @class */ (function (_super) {
    tslib_1.__extends(Forbidden, _super);
    function Forbidden() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return Forbidden;
}(MakeHttpError(403, 'Forbidden')));
exports.Forbidden = Forbidden;
/**
 * Creates a `NotFound` error.
 */
var NotFound = /** @class */ (function (_super) {
    tslib_1.__extends(NotFound, _super);
    function NotFound() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return NotFound;
}(MakeHttpError(404, 'Not Found')));
exports.NotFound = NotFound;
/**
 * Creates a `MethodNotAllowed` error.
 */
var MethodNotAllowed = /** @class */ (function (_super) {
    tslib_1.__extends(MethodNotAllowed, _super);
    function MethodNotAllowed() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return MethodNotAllowed;
}(MakeHttpError(405, 'Method Not Allowed')));
exports.MethodNotAllowed = MethodNotAllowed;
/**
 * Creates a `NotAcceptable` error.
 */
var NotAcceptable = /** @class */ (function (_super) {
    tslib_1.__extends(NotAcceptable, _super);
    function NotAcceptable() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return NotAcceptable;
}(MakeHttpError(406, 'Not Acceptable')));
exports.NotAcceptable = NotAcceptable;
/**
 * Creates a `ProxyAuthenticationRequired` error.
 */
var ProxyAuthenticationRequired = /** @class */ (function (_super) {
    tslib_1.__extends(ProxyAuthenticationRequired, _super);
    function ProxyAuthenticationRequired() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return ProxyAuthenticationRequired;
}(MakeHttpError(407, 'Proxy Authentication Required')));
exports.ProxyAuthenticationRequired = ProxyAuthenticationRequired;
/**
 * Creates a `Timeout` error.
 */
var Timeout = /** @class */ (function (_super) {
    tslib_1.__extends(Timeout, _super);
    function Timeout() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return Timeout;
}(MakeHttpError(408, 'Timeout')));
exports.Timeout = Timeout;
/**
 * Creates a `Conflict` error.
 */
var Conflict = /** @class */ (function (_super) {
    tslib_1.__extends(Conflict, _super);
    function Conflict() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return Conflict;
}(MakeHttpError(409, 'Conflict')));
exports.Conflict = Conflict;
/**
 * Creates a `Gone` error.
 */
var Gone = /** @class */ (function (_super) {
    tslib_1.__extends(Gone, _super);
    function Gone() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return Gone;
}(MakeHttpError(410, 'Gone')));
exports.Gone = Gone;
/**
 * Creates a `LengthRequired` error.
 */
var LengthRequired = /** @class */ (function (_super) {
    tslib_1.__extends(LengthRequired, _super);
    function LengthRequired() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return LengthRequired;
}(MakeHttpError(411, 'Length Required')));
exports.LengthRequired = LengthRequired;
/**
 * Creates a `PreconditionFailed` error.
 */
var PreconditionFailed = /** @class */ (function (_super) {
    tslib_1.__extends(PreconditionFailed, _super);
    function PreconditionFailed() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return PreconditionFailed;
}(MakeHttpError(412, 'Precondition Failed')));
exports.PreconditionFailed = PreconditionFailed;
/**
 * Creates a `PayloadTooLarge` error.
 */
var PayloadTooLarge = /** @class */ (function (_super) {
    tslib_1.__extends(PayloadTooLarge, _super);
    function PayloadTooLarge() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return PayloadTooLarge;
}(MakeHttpError(413, 'Payload Too Large')));
exports.PayloadTooLarge = PayloadTooLarge;
/**
 * Creates a `UriTooLong` error.
 */
var UriTooLong = /** @class */ (function (_super) {
    tslib_1.__extends(UriTooLong, _super);
    function UriTooLong() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return UriTooLong;
}(MakeHttpError(414, 'URI Too Long')));
exports.UriTooLong = UriTooLong;
/**
 * Creates a `UnsupportedMediaType` error.
 */
var UnsupportedMediaType = /** @class */ (function (_super) {
    tslib_1.__extends(UnsupportedMediaType, _super);
    function UnsupportedMediaType() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return UnsupportedMediaType;
}(MakeHttpError(415, 'Unsupported Media Type')));
exports.UnsupportedMediaType = UnsupportedMediaType;
/**
 * Creates a `RequestRangeNotSatisfiable` error.
 */
var RequestRangeNotSatisfiable = /** @class */ (function (_super) {
    tslib_1.__extends(RequestRangeNotSatisfiable, _super);
    function RequestRangeNotSatisfiable() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return RequestRangeNotSatisfiable;
}(MakeHttpError(416, 'Request Range Not Satifiable')));
exports.RequestRangeNotSatisfiable = RequestRangeNotSatisfiable;
/**
 * Creates a `ExpectationFailed` error.
 */
var ExpectationFailed = /** @class */ (function (_super) {
    tslib_1.__extends(ExpectationFailed, _super);
    function ExpectationFailed() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return ExpectationFailed;
}(MakeHttpError(417, 'Expectation Failed')));
exports.ExpectationFailed = ExpectationFailed;
/**
 * Creates a `IAmATeapot` error.
 */
var IAmATeapot = /** @class */ (function (_super) {
    tslib_1.__extends(IAmATeapot, _super);
    function IAmATeapot() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return IAmATeapot;
}(MakeHttpError(418, 'I am a Teapot')));
exports.IAmATeapot = IAmATeapot;
/**
 * Creates a `MisdirectedRequest` error.
 */
var MisdirectedRequest = /** @class */ (function (_super) {
    tslib_1.__extends(MisdirectedRequest, _super);
    function MisdirectedRequest() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return MisdirectedRequest;
}(MakeHttpError(421, 'Misdirected Request')));
exports.MisdirectedRequest = MisdirectedRequest;
/**
 * Creates a `Unprocessable` error.
 */
var Unprocessable = /** @class */ (function (_super) {
    tslib_1.__extends(Unprocessable, _super);
    function Unprocessable() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return Unprocessable;
}(MakeHttpError(422, 'Unprocessable')));
exports.Unprocessable = Unprocessable;
/**
 * Creates a `Locked` error.
 */
var Locked = /** @class */ (function (_super) {
    tslib_1.__extends(Locked, _super);
    function Locked() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return Locked;
}(MakeHttpError(423, 'Locked')));
exports.Locked = Locked;
/**
 * Creates a `FailedDependency` error.
 */
var FailedDependency = /** @class */ (function (_super) {
    tslib_1.__extends(FailedDependency, _super);
    function FailedDependency() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return FailedDependency;
}(MakeHttpError(424, 'Failed Dependency')));
exports.FailedDependency = FailedDependency;
/**
 * Creates a `TooEarly` error.
 */
var TooEarly = /** @class */ (function (_super) {
    tslib_1.__extends(TooEarly, _super);
    function TooEarly() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return TooEarly;
}(MakeHttpError(425, 'Too Early')));
exports.TooEarly = TooEarly;
/**
 * Creates a `UpgradeRequired` error.
 */
var UpgradeRequired = /** @class */ (function (_super) {
    tslib_1.__extends(UpgradeRequired, _super);
    function UpgradeRequired() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return UpgradeRequired;
}(MakeHttpError(426, 'Upgrade Required')));
exports.UpgradeRequired = UpgradeRequired;
/**
 * Creates a `PreconditionRequired` error.
 */
var PreconditionRequired = /** @class */ (function (_super) {
    tslib_1.__extends(PreconditionRequired, _super);
    function PreconditionRequired() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return PreconditionRequired;
}(MakeHttpError(428, 'Precondition Required')));
exports.PreconditionRequired = PreconditionRequired;
/**
 * Creates a `TooManyRequests` error.
 */
var TooManyRequests = /** @class */ (function (_super) {
    tslib_1.__extends(TooManyRequests, _super);
    function TooManyRequests() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return TooManyRequests;
}(MakeHttpError(429, 'Too Many Requests')));
exports.TooManyRequests = TooManyRequests;
/**
 * Creates a `RequestHeaderFieldsTooLarge` error.
 */
var RequestHeaderFieldsTooLarge = /** @class */ (function (_super) {
    tslib_1.__extends(RequestHeaderFieldsTooLarge, _super);
    function RequestHeaderFieldsTooLarge() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return RequestHeaderFieldsTooLarge;
}(MakeHttpError(431, 'Request Header Fields Too Large')));
exports.RequestHeaderFieldsTooLarge = RequestHeaderFieldsTooLarge;
/**
 * Creates a `UnavailableForLegalReasons` error.
 */
var UnavailableForLegalReasons = /** @class */ (function (_super) {
    tslib_1.__extends(UnavailableForLegalReasons, _super);
    function UnavailableForLegalReasons() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return UnavailableForLegalReasons;
}(MakeHttpError(451, 'Unavailable For Legal Reasons')));
exports.UnavailableForLegalReasons = UnavailableForLegalReasons;
/** *********************************************
 * List of all SERVER Errors (5xx)
 */
/**
 * Creates a `GeneralError` error.
 * This is basically some kind of `InternalServerError` error.
 */
var GeneralError = /** @class */ (function (_super) {
    tslib_1.__extends(GeneralError, _super);
    function GeneralError() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return GeneralError;
}(MakeHttpError(500, 'General Error')));
exports.GeneralError = GeneralError;
/**
 * Creates a `NotImplemented` error.
 */
var NotImplemented = /** @class */ (function (_super) {
    tslib_1.__extends(NotImplemented, _super);
    function NotImplemented() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return NotImplemented;
}(MakeHttpError(501, 'Not Implemented')));
exports.NotImplemented = NotImplemented;
/**
 * Creates a `BadGateway` error.
 */
var BadGateway = /** @class */ (function (_super) {
    tslib_1.__extends(BadGateway, _super);
    function BadGateway() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return BadGateway;
}(MakeHttpError(502, 'Bad Gateway')));
exports.BadGateway = BadGateway;
/**
 * Creates a `ServiceUnavailable` error.
 */
var ServiceUnavailable = /** @class */ (function (_super) {
    tslib_1.__extends(ServiceUnavailable, _super);
    function ServiceUnavailable() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return ServiceUnavailable;
}(MakeHttpError(503, 'Service Unavailable')));
exports.ServiceUnavailable = ServiceUnavailable;
/**
 * Creates a `GatewayTimeout` error.
 */
var GatewayTimeout = /** @class */ (function (_super) {
    tslib_1.__extends(GatewayTimeout, _super);
    function GatewayTimeout() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return GatewayTimeout;
}(MakeHttpError(504, 'Gateway Timeout')));
exports.GatewayTimeout = GatewayTimeout;
/**
 * Creates a `HttpVersionNotSupported` error.
 */
var HttpVersionNotSupported = /** @class */ (function (_super) {
    tslib_1.__extends(HttpVersionNotSupported, _super);
    function HttpVersionNotSupported() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return HttpVersionNotSupported;
}(MakeHttpError(505, 'HTTP Version Not Supported')));
exports.HttpVersionNotSupported = HttpVersionNotSupported;
/**
 * Creates a `VariantAlsoNegotiates` error.
 */
var VariantAlsoNegotiates = /** @class */ (function (_super) {
    tslib_1.__extends(VariantAlsoNegotiates, _super);
    function VariantAlsoNegotiates() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return VariantAlsoNegotiates;
}(MakeHttpError(506, 'Variant Also Negotiates')));
exports.VariantAlsoNegotiates = VariantAlsoNegotiates;
/**
 * Creates a `InsufficientStorage` error.
 */
var InsufficientStorage = /** @class */ (function (_super) {
    tslib_1.__extends(InsufficientStorage, _super);
    function InsufficientStorage() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return InsufficientStorage;
}(MakeHttpError(507, 'Insufficient Storage')));
exports.InsufficientStorage = InsufficientStorage;
/**
 * Creates a `LoopDetected` error.
 */
var LoopDetected = /** @class */ (function (_super) {
    tslib_1.__extends(LoopDetected, _super);
    function LoopDetected() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return LoopDetected;
}(MakeHttpError(508, 'Loop Detected')));
exports.LoopDetected = LoopDetected;
/**
 * Creates a `NotExtended` error.
 */
var NotExtended = /** @class */ (function (_super) {
    tslib_1.__extends(NotExtended, _super);
    function NotExtended() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return NotExtended;
}(MakeHttpError(510, 'Not Extended')));
exports.NotExtended = NotExtended;
/**
 * Creates a `NetworkAuthenticationRequired` error.
 */
var NetworkAuthenticationRequired = /** @class */ (function (_super) {
    tslib_1.__extends(NetworkAuthenticationRequired, _super);
    function NetworkAuthenticationRequired() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return NetworkAuthenticationRequired;
}(MakeHttpError(511, 'Network Authentication Required')));
exports.NetworkAuthenticationRequired = NetworkAuthenticationRequired;
/**
 * Gets an error constructor for a HTTP status code.
 *
 * @param statusCode
 */
function getHttpErrorConstructorForStatusCode(statusCode) {
    /* istanbul ignore next */
    switch (statusCode) {
        case 400:
            return BadRequest;
        case 401:
            return NotAuthenticated;
        case 402:
            return PaymentRequired;
        case 403:
            return Forbidden;
        case 404:
            return NotFound;
        case 405:
            return MethodNotAllowed;
        case 406:
            return NotAcceptable;
        case 407:
            return ProxyAuthenticationRequired;
        case 408:
            return Timeout;
        case 409:
            return Conflict;
        case 410:
            return Gone;
        case 411:
            return LengthRequired;
        case 412:
            return PreconditionFailed;
        case 413:
            return PayloadTooLarge;
        case 414:
            return UriTooLong;
        case 415:
            return UnsupportedMediaType;
        case 416:
            return RequestRangeNotSatisfiable;
        case 417:
            return ExpectationFailed;
        case 418:
            return IAmATeapot;
        case 421:
            return MisdirectedRequest;
        case 422:
            return Unprocessable;
        case 423:
            return Locked;
        case 424:
            return FailedDependency;
        case 425:
            return TooEarly;
        case 426:
            return UpgradeRequired;
        case 428:
            return PreconditionRequired;
        case 429:
            return TooManyRequests;
        case 431:
            return RequestHeaderFieldsTooLarge;
        case 451:
            return UnavailableForLegalReasons;
        case 501:
            return NotImplemented;
        case 502:
            return BadGateway;
        case 503:
            return ServiceUnavailable;
        case 504:
            return GatewayTimeout;
        case 505:
            return HttpVersionNotSupported;
        case 506:
            return VariantAlsoNegotiates;
        case 507:
            return InsufficientStorage;
        case 508:
            return LoopDetected;
        case 510:
            return NotExtended;
        case 511:
            return NetworkAuthenticationRequired;
        default:
            return GeneralError;
    }
}
exports.getHttpErrorConstructorForStatusCode = getHttpErrorConstructorForStatusCode;
/**
 * Builds a HTTP status code based error class.
 *
 * @private
 * @param statusCode The status code.
 * @param message The message.
 */
function MakeHttpError(statusCode, message) {
    return make_error_class_1.MakeErrorClass(message, { statusCode: statusCode });
}
//# sourceMappingURL=http.js.map